inject_user_page_fault_handler

Function inject_user_page_fault_handler 

pub fn inject_user_page_fault_handler(handler: UserPageFaultHandler)
Injects a custom handler for page faults that occur in the kernel and are caused by user-space addresses.

The function may be called only once; subsequent calls take no effect.