UserPageFaultHandler

Type Alias UserPageFaultHandler 

pub type UserPageFaultHandler = fn(&CpuException) -> Result<(), ()>;
A handler that handles page faults caused by user-space addresses.

The page fault is described in CpuException. If it can be resolved successfully, this method will return Ok(()). Otherwise, it should return Err(()).